@@ -640,7 +640,7 @@ class RequestEntityTooLarge(ValidatorException):
             """\
             <html>\r
             <head><title>413 Request Entity Too Large</title></head>\r
-            <body bgcolor="white">\r
+            <body>\r
             <center><h1>413 Request Entity Too Large</h1></center>\r
             <hr><center>nginx</center>\r
             </body>\r
@@ -684,7 +684,9 @@ class MatchProcessing(ValidatorException):
         resources_dir = Path(__file__).parent.parent / 'resources'
         filename = 'match_processing_response.html'
         match_processing_resp_file = resources_dir / filename
-        self.response_text = Path(match_processing_resp_file).read_text()
+        self.response_text = Path(match_processing_resp_file).read_text(
+            encoding='utf-8',
+        )
         self.headers = {
             'Connection': 'keep-alive',
             'Content-Type': 'text/html;charset=iso-8859-1',
@@ -725,7 +727,7 @@ class NoContentType(ValidatorException):
             <tr><th>MESSAGE:</th><td>Bad Request</td></tr>
             <tr><th>SERVLET:</th><td>Resteasy</td></tr>
             </table>
-            <hr><a href="http://eclipse.org/jetty">Powered by Jetty:// 9.4.31.v20200723</a><hr/>
+            <hr><a href="https://eclipse.org/jetty">Powered by Jetty:// 9.4.43.v20210629</a><hr/>
 
             </body>
             </html>
